// flexp model

periods 20000;
var c p r n f;
varexo ep;

parameters gam nu rho phi theta beta delta psi dd zz m;

gam = 1.0;
nu = 3;
beta = .99;
rho = (1/beta)-1;
phi = 1;
theta = 4.8;
delta = .025;
psi = ((gam+beta*(1-delta)-1)*(phi+1)+(1-beta*(1-delta))*(1+gam*phi)*(theta-1))/((theta-1)*(1+gam*phi));
dd = (1/(1-beta*(1-delta))-1);
zz = 0;
m = 0;

model(linear);
nu*(m-p) = gam*c-r/rho;
n = ((1+gam*phi)*(theta-1)/(phi+1))*c+(1-theta)*zz;
-gam*c = r-gam*c(+1)-(p(+1)-p);
-gam*c = (1-beta*(1-delta)-gam)*c(+1)-(1-beta*(1-delta))*n(+1)+beta*(1-delta)*f(+1)-f;
f = .9*f(-1)-ep;
end;

initval;
f = 0;
c = 0;
p = 0;
r = 0;
n = 0;
ep = 0;
end;

steady;
check;

shocks;
var ep;
periods 1;
values 1;
end;


simul(periods=100);

%dsample 0 50;
%rplot c;
%rplot p;
%rplot r;
%rplot n;
%rplot f;

plot(n,'b+'); hold on; plot(p,'ro'); hold off;
title('Plot of n, p, with temp. pos. shock to f');
legend('n','p');